# Core Geometry Subsystem

The core geometry subsystem is responsible for calculating the geometric properties of the aircraft.
This includes the wing area, wing span, fuselage length, tail properties, passenger and cargo capacity, and other geometric properties.

```{note}
This section is under further development.
```
